==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebPathSegmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPathSegmentDescription } from "./WebPathSegmentDescription";
/**
 * @hidden
 */
var WebPathSegmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPathSegmentDescriptionMetadata, _super);
    function WebPathSegmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPathSegmentDescriptionMetadata.b = function (a) {
        if (WebPathSegmentDescriptionMetadata.a == null) {
            WebPathSegmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPathSegmentDescriptionMetadata.c(WebPathSegmentDescriptionMetadata.a);
        }
        if (a.j(WebPathSegmentDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPathSegmentDescriptionMetadata.a);
    };
    WebPathSegmentDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PathSegment");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("RowID", "Unknown");
        a.item("RowIslandKey", "String");
    };
    WebPathSegmentDescriptionMetadata.d = function (a) {
        WebPathSegmentDescriptionMetadata.b(a);
        a.aa("WebPathSegment", function () { return new WebPathSegmentDescription(); });
        a.z("WebPathSegment", WebPathSegmentDescriptionMetadata.a);
    };
    WebPathSegmentDescriptionMetadata.$t = markType(WebPathSegmentDescriptionMetadata, 'WebPathSegmentDescriptionMetadata');
    WebPathSegmentDescriptionMetadata.a = null;
    return WebPathSegmentDescriptionMetadata;
}(Base));
export { WebPathSegmentDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPathSegmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPathSegmentDescription } from "./WebPathSegmentDescription";
/**
 * @hidden
 */
var WebPathSegmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPathSegmentDescriptionMetadata, _super);
    function WebPathSegmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPathSegmentDescriptionMetadata.b = function (a) {
        if (WebPathSegmentDescriptionMetadata.a == null) {
            WebPathSegmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPathSegmentDescriptionMetadata.c(WebPathSegmentDescriptionMetadata.a);
        }
        if (a.k(WebPathSegmentDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPathSegmentDescriptionMetadata.a);
    };
    WebPathSegmentDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PathSegment");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("RowID", "Unknown");
        a.item("RowIslandKey", "String");
    };
    WebPathSegmentDescriptionMetadata.d = function (a) {
        WebPathSegmentDescriptionMetadata.b(a);
        a.ac("WebPathSegment", function () { return new WebPathSegmentDescription(); });
        a.ab("WebPathSegment", WebPathSegmentDescriptionMetadata.a);
    };
    WebPathSegmentDescriptionMetadata.$t = markType(WebPathSegmentDescriptionMetadata, 'WebPathSegmentDescriptionMetadata');
    WebPathSegmentDescriptionMetadata.a = null;
    return WebPathSegmentDescriptionMetadata;
}(Base));
export { WebPathSegmentDescriptionMetadata };
